pub struct RulesetVersion(pub String);Expand description
Semver-shaped version for a ruleset, tracking parameter changes across delegated-act amendments.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for RulesetVersion
impl Clone for RulesetVersion
Sourcefn clone(&self) -> RulesetVersion
fn clone(&self) -> RulesetVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RulesetVersion
impl Debug for RulesetVersion
Sourceimpl<'de> Deserialize<'de> for RulesetVersion
impl<'de> Deserialize<'de> for RulesetVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RulesetVersion
Sourceimpl PartialEq for RulesetVersion
impl PartialEq for RulesetVersion
Sourcefn eq(&self, other: &RulesetVersion) -> bool
fn eq(&self, other: &RulesetVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RulesetVersion
impl Serialize for RulesetVersion
impl StructuralPartialEq for RulesetVersion